@@ -512,13 +512,8 @@ static void
 set_timeout (void)
 {
 	static guint update_timeout_id = 0;
-	gboolean should_timeout;
-	
-	if (add_notifies || g_hash_table_size (printers) > 0) {
-		should_timeout = TRUE;
-	} else {
-		should_timeout = FALSE;
-	}	
+	gboolean should_timeout =
+		add_notifies || (printers != NULL && g_hash_table_size (printers) > 0);
 
 	if (should_timeout && !update_timeout_id) {
 		update_timeout_id = g_timeout_add (UPDATE_TIMEOUT, 
@@ -957,11 +952,12 @@ get_option (ppd_option_t *option)
 {
 	GnomeCupsPrinterOption *ret;
 	int i;
+	char *defchoice;
+	char *p;
 	
 	ret = g_new0 (GnomeCupsPrinterOption, 1);
 	ret->id = g_strdup (option->keyword);
 	ret->text = g_strdup (option->text);
-	ret->value = g_strdup (option->defchoice);
 	ret->type = option->ui;
 	ret->n_choices = option->num_choices;
 	ret->choices = g_new0 (GnomeCupsPrinterOptionChoice, ret->n_choices);
@@ -970,6 +966,18 @@ get_option (ppd_option_t *option)
 		ret->choices[i].text = g_strdup (option->choices[i].text);
 	}
 
+	defchoice = g_strdup (option->defchoice);
+	
+	/* Strip trailing spaces and tabs since CUPS doesn't does this
+	 */
+	p = defchoice + strlen (defchoice);
+	while (p > defchoice &&
+	       (*(p - 1) == ' ' || *(p - 1) == '\t')) {
+		*(p - 1) = '\0';
+		p--;
+	}
+	ret->value = defchoice;
+
 	return ret;
 }
 
@@ -1388,6 +1396,11 @@ gnome_cups_printer_print_file (GnomeCupsPrinter *printer,
 	cups_option_t *cups_options;
 	GList *l;
 
+	g_return_val_if_fail (printer != NULL, FALSE);
+	g_return_val_if_fail (GNOME_CUPS_IS_PRINTER (printer), FALSE);
+	g_return_val_if_fail (printer->details != NULL, FALSE);
+	g_return_val_if_fail (printer->details->printer_name != NULL, FALSE);
+
 	num_options = g_list_length (options);
 
 	if (num_options > 0) {
